pub struct Orderbook {
pub base: Address,
pub quote: Address,
bids: Mapping<i16, TickLevel>,
asks: Mapping<i16, TickLevel>,
pub best_bid_tick: i16,
pub best_ask_tick: i16,
bid_bitmap: Mapping<i16, U256>,
ask_bitmap: Mapping<i16, U256>,
}Expand description
Orderbook for token pair with price-time priority Uses tick-based pricing with bitmaps for price discovery
Fields
base: AddressBase token address
quote: AddressQuote token address
bids: Mapping<i16, TickLevel>Bid orders by tick
asks: Mapping<i16, TickLevel>Ask orders by tick
best_bid_tick: i16Best bid tick for highest bid price
best_ask_tick: i16Best ask tick for lowest ask price
bid_bitmap: Mapping<i16, U256>Mapping of tick index to bid bitmap for price discovery
ask_bitmap: Mapping<i16, U256>Mapping of tick index to ask bitmap for price discovery
Implementations
Sourceimpl Orderbook
impl Orderbook
Sourcepub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Returns true if this orderbook is initialized
Sourcepub fn matches_tokens(
&self,
base_token: Option<Address>,
quote_token: Option<Address>,
) -> bool
pub fn matches_tokens( &self, base_token: Option<Address>, quote_token: Option<Address>, ) -> bool
Returns true if the base and quote tokens match the provided base and quote token options.